# OntoAligner: A Ontology Alignment Python Library

<div align="center">
<h4><span align="center" style="color: red;">🔴🔴🔴🔴Under Construction🔴🔴🔴🔴</span></h4>
</div>

[//]: # ()
[//]: # (<div align="center">)
[//]: # (  <img src=" "/>)
[//]: # (</div>)

[//]: # (<div align="center">OntoAligner: A Ontology Alignment Python Library </div> <br>)

<div align="center">

![PyPI Version](https://img.shields.io/pypi/v/OntoAligner?color=blue)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)

</div>


**OntoAligner** is a Python library built to make ontology alignment/matching easy for everyone in the community!

## Installation
OntoAligner is available on PyPI and can be installed with pip:
```
pip install ontoaligner
```

You can also install the latest version from the source:
```
git clone https://github.com/hamedbabaei/ontoaligner.git
pip install ./ontoaligner
```
## Documentation

## Quick Tour

## Contribution
We welcome contributions of any and greatly value your support in enhancing OntoAligner.  Before getting started, please review our contribution guidelines in [CONTRIBUTING.md](CONTRIBUTING.md). Your involvement is sincerely appreciated!

## Contact
We highly recommend to submit any issues or questions in the issues.

## Citation
If you found this project useful in your work or research please cite the following works:

```bibtex
@misc{giglou2024llms4om,
      title={LLMs4OM: Matching Ontologies with Large Language Models},
      author={Hamed Babaei Giglou and Jennifer D'Souza and Felix Engel and Sören Auer},
      year={2024},
      eprint={2404.10317},
      archivePrefix={arXiv},
      primaryClass={cs.AI}
}
```

```bibtex
@software{babaei_giglou_ontoaligner_2024,
  author       = {Hamed Babaei Giglou and Sameer Sadruddin and Jennifer D'Souza and Sören Auer},
  title        = {OntoAligner: An Ontology Alignment Python Library},
  version      = {0.1.0},
  year         = {2024},
  url          = {https://github.com/HamedBabaei/OntoAligner},
}
```
